==> synpay-8.x-1.2.tar.gz: synpay/src/Controller/PayController.php <==
<?php

namespace Drupal\synpay\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;
use Drupal\Core\Routing\TrustedRedirectResponse;
use Symfony\Component\HttpFoundation\Response;
use Drupal\commerce_order\Entity\Order;

/**
 * Returns responses for zakaz routes.
 */
class PayController extends ControllerBase {

  /**
   * Pay page.
   */
  public function page(string $plugin_name, string $order, string $total) {
    $manager = \Drupal::service('plugin.manager.synpay');
    $defi = $manager->getDefinitions();
    $c = 0;
    foreach ($defi as $id => $row) {
      if ($row['id'] == $plugin_name) {
        $c++;
      }
    }
    if ($c != 0) {
      $plugin = $manager->createInstance($plugin_name, [
        'order' => $order,
        'total' => floatval($total),
      ]);
      switch ($plugin->active) {
        case 0:
          return [
            '#markup' => '',
          ];

        default:
          $form = \Drupal::formBuilder()->getForm('Drupal\synpay\Form\PayForm', $plugin);
          $build['form'] = $form;
          break;
      }
      return $build;
    }
    else {
      \Drupal::messenger()->addWarning(t("Gateway does not exist!"));
      \Drupal::messenger()->addWarning(t("Please check configuration."));
      return [
        '#markup' => '',
      ];
    }
  }

  /**
   * CallBack (for robots)
   */
  public function callback(string $plugin_name, Request $request) {
    $manager = \Drupal::service('plugin.manager.synpay');
    $plugin = $manager->createInstance($plugin_name, []);
    if ($plugin) {
      $order_status = $plugin->callback($request);
      $payment_storage = \Drupal::entityTypeManager()->getStorage('commerce_payment');
      $payment = $payment_storage->loadByRemoteId($order_status['order_id']);
      $this->order = $order = Order::load($payment->getOrderId());
      $step_id = $order->get('checkout_step')->getValue()[0]['value'];
      $checkout_flow = $order->get('checkout_flow')->entity;
      $checkout_flow_plugin = $checkout_flow->getPlugin();
      switch ($order_status['status']) {
        case 'completed':
          $payment->setState('completed');
          $payment->setRemoteState('paid');
          $payment->save();
          $redirect_step_id = $checkout_flow_plugin->getNextStepId($step_id);
          $this->redirectToStep($redirect_step_id);
          return new Response("OK{$order_status['order_id']}", 200);

        default:
          $previous_step_id = $checkout_flow_plugin->getPreviousStepId($step_id);
          $this->redirectToStep($previous_step_id);
          return new Response("Error{$order_status['order_id']}", 406);
      }
    }
    return [
      "#markup" => '',
    ];
  }

  /**
   * Return (for users) only for Robokassa.
   */
  public function return(string $plugin_name, Request $request) {
    $manager = \Drupal::service('plugin.manager.synpay');
    $plugin = $manager->createInstance($plugin_name, []);
    if ($plugin) {
      $order_status = $plugin->return($request);
      $redirect = "/checkout/{$order_status['order_id']}/";

      switch ($order_status['status']) {
        case 'completed':
          $redirect .= "complete";
          \Drupal::messenger()->addMessage($this->t("Payment completed successfully!"));
          break;

        default:
        case 'authorization_voided':
          $redirect .= "review";
          $message = $this->t("Payment not completed! Please contact support!");
          \Drupal::messenger()->addError($message);

      }
    }
    $response = new TrustedRedirectResponse($redirect);
    $response->send();
    return [
      "#markup" => '',
    ];
  }

  /**
   * Return (for direct payments).
   */
  public function returnDirect(string $plugin_name, Request $request) {
    $manager = \Drupal::service('plugin.manager.synpay');
    $plugin = $manager->createInstance($plugin_name, []);
    if ($plugin) {
      $order_status = $plugin->callback($request);
      switch ($order_status['status']) {
        case 'completed':
          $text = $this->t("Payment completed successfully!");
          // return new Response("OK{$order_status['order_id']}", 200);
          break;

        default:
          $text = $this->t("Payment not completed! Please contact support!");
          // return new Response("Error{$order_status['order_id']}", 406);
          break;
      }
    }
    return [
      "#markup" => $text,
    ];
  }

  /**
   * Redirect To Step.
   */
  public function redirectToStep($step_id) {
    $this->order->set('checkout_step', $step_id);
    if ($step_id == 'payment') {
      $this->order->lock();
    }
    elseif ($step_id != 'payment') {
      $this->order->unlock();
    }
    // Place the order.
    if ($step_id == 'complete' && $this->order->getState()->getId() == 'draft') {
      $this->order->getState()->applyTransitionById('place');
    }
    $this->order->save();
  }

  /**
   * Title Callback.
   */
  public function title() {
    return $this->t("Custom Pay");
  }

}

==> synpay-8.x-1.5.tar.gz: synpay/src/Controller/PayController.php <==
<?php

namespace Drupal\synpay\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;
use Drupal\Core\Routing\TrustedRedirectResponse;
use Symfony\Component\HttpFoundation\Response;
use Drupal\commerce_order\Entity\Order;

/**
 * Returns responses for zakaz routes.
 */
class PayController extends ControllerBase {

  /**
   * Pay page.
   */
  public function page(string $plugin_name, string $order, string $total) {
    $manager = \Drupal::service('plugin.manager.synpay');
    $defi = $manager->getDefinitions();
    $c = 0;
    foreach ($defi as $id => $row) {
      if ($row['id'] == $plugin_name) {
        $c++;
      }
    }
    if ($c != 0) {
      $plugin = $manager->createInstance($plugin_name, [
        'order' => $order,
        'total' => floatval($total),
      ]);
      switch ($plugin->active) {
        case 0:
          return [
            '#markup' => '',
          ];

        default:
          $form = \Drupal::formBuilder()->getForm('Drupal\synpay\Form\PayForm', $plugin);
          $build['form'] = $form;
          break;
      }
      return $build;
    }
    else {
      \Drupal::messenger()->addWarning(t("Gateway does not exist!"));
      \Drupal::messenger()->addWarning(t("Please check configuration."));
      return [
        '#markup' => '',
      ];
    }
  }

  /**
   * CallBack (for robots)
   */
  public function callback(string $plugin_name, Request $request) {
    $manager = \Drupal::service('plugin.manager.synpay');
    $plugin = $manager->createInstance($plugin_name, []);
    if ($plugin) {
      $order_status = $plugin->callback($request);
      $payment_storage = \Drupal::entityTypeManager()->getStorage('commerce_payment');
      $payment = $payment_storage->loadByRemoteId($order_status['remote_id']);
      $this->order = $order = Order::load($payment->getOrderId());
      $step_id = $order->get('checkout_step')->getValue()[0]['value'];
      $checkout_flow = $order->get('checkout_flow')->entity;
      $checkout_flow_plugin = $checkout_flow->getPlugin();
      switch ($order_status['status']) {
        case 'completed':
          $payment->setState('completed');
          $payment->setRemoteState('paid');
          $payment->save();
          $redirect_step_id = $checkout_flow_plugin->getNextStepId($step_id);
          $this->redirectToStep($redirect_step_id);
          return new Response("OK{$order_status['order_id']}", 200);

        default:
          $previous_step_id = $checkout_flow_plugin->getPreviousStepId($step_id);
          $this->redirectToStep($previous_step_id);
          return new Response("Error{$order_status['order_id']}", 406);
      }
    }
    return [
      "#markup" => '',
    ];
  }

  /**
   * Return (for users) only for Robokassa.
   */
  public function return(string $plugin_name, Request $request) {
    $manager = \Drupal::service('plugin.manager.synpay');
    $plugin = $manager->createInstance($plugin_name, []);
    if ($plugin) {
      $order_status = $plugin->return($request);
      $redirect = "/checkout/{$order_status['order_id']}/";

      switch ($order_status['status']) {
        case 'completed':
          $redirect .= "complete";
          \Drupal::messenger()->addMessage($this->t("Payment completed successfully!"));
          break;

        default:
        case 'authorization_voided':
          $redirect .= "review";
          $message = $this->t("Payment not completed! Please contact support!");
          \Drupal::messenger()->addError($message);

      }
    }
    $response = new TrustedRedirectResponse($redirect);
    $response->send();
    return [
      "#markup" => '',
    ];
  }

  /**
   * Return (for direct payments).
   */
  public function returnDirect(string $plugin_name, Request $request) {
    $manager = \Drupal::service('plugin.manager.synpay');
    $plugin = $manager->createInstance($plugin_name, []);
    if ($plugin) {
      $order_status = $plugin->callback($request);
      switch ($order_status['status']) {
        case 'completed':
          $text = $this->t("Payment completed successfully!");
          break;

        default:
          $text = $this->t("Payment not completed! Please contact support!");
          $text .= "<br>{$order_status['status']}";
          break;
      }
    }
    return [
      "#markup" => $text,
    ];
  }

  /**
   * Redirect To Step.
   */
  public function redirectToStep($step_id) {
    $this->order->set('checkout_step', $step_id);
    if ($step_id == 'payment') {
      $this->order->lock();
    }
    elseif ($step_id != 'payment') {
      $this->order->unlock();
    }
    // Place the order.
    if ($step_id == 'complete' && $this->order->getState()->getId() == 'draft') {
      $this->order->getState()->applyTransitionById('place');
    }
    $this->order->save();
  }

  /**
   * Title Callback.
   */
  public function title() {
    return $this->t("Custom Pay");
  }

}
